@@ -16,7 +16,7 @@ FUEL = [autogas, diesel, erdgas, superplus, super, normal]
 
 class ITBObject:
     def __init__(self):
-        self.version = "1.0.19"
+        self.version = "1.0.20"
         self.author = "Ludy87"
         self.project = "Py Ich tanke billig"
         self.page = "https://www.astra-g.org/"
@@ -196,3 +196,67 @@ def getStationsA(kraftstoffe = FUEL, place_plz = '123', limit = '-1', asJson = F
     if asJson:
         return toJSON(stations)
     return (stations)
+
+def getStationsB(kraftstoffe = FUEL, place_plz = '123', limit = -1, asJson = False):
+    stations = {}
+    for kraftstoff in kraftstoffe:
+        me = ITBObject()
+        url = baseURL + '&sprit=' + kraftstoff + '&ort=' + urllib.parse.quote(place_plz)
+        data = connenctionLib(url)
+        text = data.decode('utf-8')
+        bs = BeautifulSoup(text, 'html.parser')
+        rows = bs.find_all('tr')
+        if len(rows) == 0:
+            info_msg = bs.find('div', {"class": "frn_contHead"})
+            if info_msg != None:
+                stations["error"] = info_msg.getText()
+            else:
+                stations["error"] = bs.getText().strip()
+        else:
+            stations['status'] = 200
+            stations[kraftstoff] = []
+
+            i = 0
+            for row in rows:
+                if not row.text.strip():
+                    continue
+                if not row.find('td'):
+                    continue
+                colErg1 = row.find('td', {"class": "colErg1"})
+                colErg2 = row.find('td', {"class": "colErg2"})
+                colErg3 = row.find('td', {"class": "colErg3"})
+
+                colErg1_a = colErg1.getText().strip().split('<br>')[0].split('\n')
+                if len(colErg1_a) < 3:
+                    me.status = {"error": 403}
+                else:
+                    stationName = colErg1_a[0].strip()
+                    street = colErg1_a[1].strip()
+                    place = colErg1_a[2].strip()
+                    plz = place.split()[0]
+                    ort = place.split()[1]
+
+                    price = colErg2.getText().strip()
+
+                    reloaded = colErg3.getText().strip().split('<br>')[0].split('\n')
+                    reloaded = reloaded[1].strip() + " " + reloaded[0].strip()
+                    sum = stationName + street + place
+                    sum = hashlib.md5(sum.encode()).hexdigest()
+                    json_data = {
+                        "id": sum,
+                        "station_name": stationName,
+                        "street": street,
+                        "place": ort,
+                        "plz": plz,
+                        "price": price,
+                        "reloaded": reloaded,
+                        "fuel": kraftstoff,
+                        "pos": i +1,
+                    }
+                    if limit == i and limit != -1:
+                        break
+                    i += 1
+                    stations[kraftstoff].append(json_data)
+    if asJson:
+        return toJSON(stations)
+    return (stations)
